@@ -1015,13 +1015,14 @@ info_panel_setup_selector (CcInfoPanel  *self)
 }
 
 static char *
-info_panel_get_hostname (CcInfoPanel  *self)
+get_hostname_property (CcInfoPanel *self,
+		       const char  *property)
 {
   GVariant *variant;
   char *str;
 
   variant = g_dbus_proxy_get_cached_property (self->priv->hostnamed_proxy,
-                                              "PrettyHostname");
+                                              property);
   if (!variant)
     {
       GError *error = NULL;
@@ -1031,14 +1032,14 @@ info_panel_get_hostname (CcInfoPanel  *self)
        * the property value when changing values */
       variant = g_dbus_proxy_call_sync (self->priv->hostnamed_proxy,
                                         "org.freedesktop.DBus.Properties.Get",
-                                        g_variant_new ("(ss)", "org.freedesktop.hostname1", "PrettyHostname"),
+                                        g_variant_new ("(ss)", "org.freedesktop.hostname1", property),
                                         G_DBUS_CALL_FLAGS_NONE,
                                         -1,
                                         NULL,
                                         &error);
       if (variant == NULL)
         {
-          g_warning ("Failed to get property 'PrettyHostname': %s", error->message);
+          g_warning ("Failed to get property '%s': %s", property, error->message);
           g_error_free (error);
           return NULL;
         }
@@ -1053,28 +1054,36 @@ info_panel_get_hostname (CcInfoPanel  *self)
       g_variant_unref (variant);
     }
 
+  return str;
+}
+
+static char *
+info_panel_get_hostname (CcInfoPanel  *self)
+{
+  char *str;
+
+  str = get_hostname_property (self, "PrettyHostname");
+
   /* Empty strings means that we need to fallback */
   if (str != NULL &&
       *str == '\0')
     {
       g_free (str);
-      str = NULL;
+      str = get_hostname_property (self, "Hostname");
     }
 
   return str;
 }
 
 static void
-text_changed_cb (GtkEntry        *entry,
-                 CcInfoPanel     *self)
+info_panel_set_hostname (CcInfoPanel *self,
+                         const char  *text)
 {
-  const char *text;
   char *hostname;
   GVariant *variant;
   GError *error = NULL;
 
-  text = gtk_entry_get_text (GTK_ENTRY (entry));
-
+  g_debug ("Setting PrettyHostname to '%s'", text);
   variant = g_dbus_proxy_call_sync (self->priv->hostnamed_proxy,
                                     "SetPrettyHostname",
                                     g_variant_new ("(sb)", text, FALSE),
@@ -1094,6 +1103,7 @@ text_changed_cb (GtkEntry        *entry,
   hostname = pretty_hostname_to_static (text, FALSE);
   g_assert (hostname);
 
+  g_debug ("Setting StaticHostname to '%s'", hostname);
   variant = g_dbus_proxy_call_sync (self->priv->hostnamed_proxy,
                                     "SetStaticHostname",
                                     g_variant_new ("(sb)", hostname, FALSE),
@@ -1111,6 +1121,16 @@ text_changed_cb (GtkEntry        *entry,
   g_free (hostname);
 }
 
+static void
+text_changed_cb (GtkEntry        *entry,
+                 CcInfoPanel     *self)
+{
+  const char *text;
+
+  text = gtk_entry_get_text (GTK_ENTRY (entry));
+  info_panel_set_hostname (self, text);
+}
+
 static void
 info_panel_setup_hostname (CcInfoPanel  *self,
                            GPermission  *permission)
@@ -1140,7 +1160,10 @@ info_panel_setup_hostname (CcInfoPanel  *self,
   g_assert (self->priv->hostnamed_proxy);
 
   str = info_panel_get_hostname (self);
-  gtk_entry_set_text (GTK_ENTRY (entry), str);
+  if (str != NULL)
+    gtk_entry_set_text (GTK_ENTRY (entry), str);
+  else
+    gtk_entry_set_text (GTK_ENTRY (entry), "");
   g_free (str);
 
   g_signal_connect (G_OBJECT (entry), "changed",
